@@ -1,7 +1,7 @@
 package Bencher::Formatter::RoundNumbers;
 
 our $DATE = '2016-10-09'; # DATE
-our $VERSION = '1.024'; # VERSION
+our $VERSION = '1.025'; # VERSION
 
 use 5.010001;
 use strict;
@@ -31,7 +31,7 @@ sub munge_result {
 
     for my $rit (@{$envres->[2]}) {
         my $num_significant_digits = do {
-            if ($rit->{errors} == 0) {
+            if (!defined($rit->{errors}) || $rit->{errors} == 0) {
                 6;
             } elsif (exists $rit->{time}) {
                 sprintf("%d", log( abs($rit->{time}) /
@@ -45,7 +45,8 @@ sub munge_result {
         if (exists $rit->{rate}) {
             $rit->{rate} = $code_fmt->($num_significant_digits, $rit->{rate});
         }
-        $rit->{errors} = $code_fmt->(2, $rit->{errors}, 1);
+        $rit->{errors} = $code_fmt->(2, $rit->{errors}, 1)
+            if defined $rit->{errors};
 
         # XXX this formatter shouldn't be aware directly of mod_overhead_time
         if (exists $rit->{mod_overhead_time}) {
@@ -85,7 +86,7 @@ Bencher::Formatter::RoundNumbers - Round numbers (rate, time) to certain signifi
 
 =head1 VERSION
 
-This document describes version 1.024 of Bencher::Formatter::RoundNumbers (from Perl distribution Bencher-Backend), released on 2016-10-09.
+This document describes version 1.025 of Bencher::Formatter::RoundNumbers (from Perl distribution Bencher-Backend), released on 2016-10-09.
 
 =for Pod::Coverage .*
 
